
==================================
 API Reference (work in progress)
==================================

.. testsetup::

    from skyfield.positionlib import *

Positions
=========

.. autoclass:: skyfield.positionlib.ICRS
   :members:

.. autoclass:: skyfield.positionlib.Barycentric
   :members:

.. autoclass:: skyfield.positionlib.Astrometric
   :members:

.. autoclass:: skyfield.positionlib.Apparent
   :members:

.. autoclass:: skyfield.positionlib.Geocentric
   :members:

Time
====

.. autofunction:: skyfield.api.now

.. autoclass:: skyfield.api.JulianDate
   :members:
